@@ -48,7 +48,7 @@ class Rule(db.Entity):
 
 
 class Connection:
-    def __init__(self, db_url: str = None):
+    def __init__(self, db_url: str = None, create_tables: bool = False):
         db_url = db_url or os.environ.get("ENTITYSCAN_DB_URL")
         db_bind_params = parse_url(db_url)
 
@@ -57,7 +57,7 @@ class Connection:
             Rule._table_ = table
 
         db.bind(**db_bind_params)
-        db.generate_mapping(create_tables=True)
+        db.generate_mapping(create_tables=create_tables)
 
     @classmethod
     def close(cls):
