@@ -20,31 +20,13 @@ from entityscan import (
 
 class Scanner:
 
-    _scanner = None
-
-    def __init__(
-        self,
-        db_url: str = None,
-        connection: Connection = None,
-        encoding: str = None,
-    ):
-        assert db_url or connection, "Missing both db url or connection."
-        self.db_url = db_url
-        self.connection = connection or Connection(db_url=db_url)
+    def __init__(self, connection: Connection = None, encoding: str = None):
+        self.connection = connection
         self.encoding = encoding or "UTF-8"
         self.patterns = engines.PatternEngine(encoding=self.encoding)
         self.composites = engines.CompositeEngine()
         self.literals = engines.LiteralEngine()
 
-    @classmethod
-    def instance(cls, db_url: str, encoding: str = None):
-        if not cls._scanner:
-            cls._scanner = cls(db_url=db_url, encoding=encoding)
-            cls._scanner.compile()
-        else:
-            assert db_url == cls._scanner.db_url, "Incongruent DB URL"
-        return cls._scanner
-
     @orm.db_session
     def load_rules(self, rules_jsonl: Path):
         assert rules_jsonl.suffix == ".jsonl", "Only supports JSONL files."
@@ -53,7 +35,6 @@ class Scanner:
             if line and line.startswith("{"):
                 try:
                     kw = json.loads(line)
-                    kw["has_groups"] = "(?P<" in kw.get("pattern", "")
                     Rule(**kw)
                 except json.JSONDecodeError:
                     logger.exception(f"JSON Fail: {line[:30]}...{line[-30:]}")
@@ -94,7 +75,8 @@ class Scanner:
         return entities
 
     def parse(self, text: str, pipeline: str = None) -> Doc:
-        return Doc(text=text, entities=self.scan(text))
+        entities = self.scan(text=text, pipeline=pipeline)
+        return Doc(text=text, entities=entities)
 
     def find(self, text: str, labels: Iterable[str] = None) -> List[Entity]:
         entities = self.scan(text)
